@@ -2,7 +2,7 @@
 from typing import NoReturn
 
 from botx.clients.methods.base import APIErrorResponse, BotXMethod
-from botx.clients.methods.wrappers import HTTPResponse
+from botx.clients.types.http import HTTPResponse
 from botx.exceptions import BotXAPIError
 
 
@@ -26,6 +26,6 @@ def handle_error(method: BotXMethod, response: HTTPResponse) -> NoReturn:
     raise UserNotFoundError(
         url=method.url,
         method=method.http_method,
-        response_content=response.bytes_body,
+        response_content=response.json_body,
         status_content=response.status_code,
     )
