@@ -1,16 +1,7 @@
 """Message that is sent from bot."""
 import re
-from typing import (  # noqa: WPS235
-    Any,
-    BinaryIO,
-    Dict,
-    List,
-    Optional,
-    TextIO,
-    Tuple,
-    Union,
-    cast,
-)
+from typing import Any  # noqa: WPS235
+from typing import BinaryIO, Dict, List, Optional, TextIO, Tuple, Union, cast
 from uuid import UUID
 
 from botx.models.buttons import ButtonOptions
@@ -33,13 +24,13 @@ ARGUMENTS_DUPLICATION_ERROR = (
     "{0} can not be passed along with manual validated_values for it"
 )
 
-EMBED_MENTION_TEMPATE = (
+EMBED_MENTION_TEMPLATE = (
     "<embed_mention:{mention_type}:"
     "{mentioned_entity_id}:{mention_id}:{mention_name}>"  # noqa: WPS326
 )
 EMBED_MENTION_RE: Final = re.compile(
-    "<embed_mention:(?P<mention_type>.+?):(?P<mentioned_entity_id>.+?)"
-    ":(?P<mention_id>.+?):(?P<name>.+?)?>",  # noqa: WPS326 C812
+    r"<embed_mention:(?P<mention_type>.+?):(?P<mentioned_entity_id>[0-9a-f\-]+?):"
+    r"(?P<mention_id>[0-9a-f\-]+?):(?P<name>.+?)??>",  # noqa: WPS326 C812
 )
 
 
@@ -137,6 +128,7 @@ class SendingMessage:  # noqa: WPS214
         text: str = "",
         file: Optional[File] = None,
         message: Message,
+        embed_mentions: bool = False,
     ) -> "SendingMessage":
         """Build message for sending from incoming message.
 
@@ -144,6 +136,7 @@ class SendingMessage:  # noqa: WPS214
             text: text for message.
             file: file attached to message.
             message: incoming message.
+            embed_mentions: get mentions from text.
 
         Returns:
             Built message.
@@ -155,6 +148,7 @@ class SendingMessage:  # noqa: WPS214
             chat_id=message.group_chat_id,
             bot_id=message.bot_id,
             host=message.host,
+            embed_mentions=embed_mentions,
         )
 
     @classmethod
@@ -181,7 +175,7 @@ class SendingMessage:  # noqa: WPS214
 
         mention_name = mention.mention_data.name or ""
 
-        return EMBED_MENTION_TEMPATE.format(
+        return EMBED_MENTION_TEMPLATE.format(
             mention_type=mention.mention_type,
             mentioned_entity_id=mentioned_entity_id,
             mention_id=mention.mention_id,
